# Z0Z_tools

"Z0Z_"- is a placeholder, and a Z0Z_tool is at best, a prototype.

## Do you also get irritated by "'true' is invalid and stupid. Did you mean 'True'?"

`oopsieKwargsie()` will try to interpret an errant parameter value as `True`, `False`, or `None`.

## Allow a calling function to limit concurrency to a ratio, absolute count, or relative count with `defineConcurrencyLimit()`

## Install an arbitrary package with `pipAnything`

Try to install a package that doesn't have installation files.

```sh
python -m Z0Z_tools.pipAnything <pathPackage>
```

## Unpack and convert elements to `str` types with `stringItUp()`

## Merge and/or lightly clean a dictionary of lists with `updateExtendPolishDictionaryLists()`

- Merges multiple dictionaries of lists into a single dictionary.
- Optionally remove duplicates each list.
- Optionally sort each list.
- Optionally delete data that won't merge.

## Easily read/write WAV files with `readAudioFile()` and `writeWav()`

The only option is the sample rate.

## Use `loadWaveforms()` to create one array of waveforms from multiple files

## Install this package

```sh
pip install Z0Z-tools
```
